@@ -33,7 +33,7 @@ FEATURES="test_validate_all,test_random_chunk_action"
 # FEATURES="test_validate_all"
 
 (cd "$HERE/..";
- cargo build  --release --target-dir "$CURRENT" --no-default-features --features "$FEATURES")
+ RUSTFLAGS=-g cargo build  --release --target-dir "$CURRENT" --no-default-features --features "$FEATURES")
 
 # We want sqlite to call our test-only registration function, which
 # will mark the verneuil VFS as the one, and pretend it's the Unix
@@ -67,7 +67,15 @@ mkdir -p minio
 rm -rf minio
 mkdir -p minio
 
-docker run --net=host \
+EXTRA_DOCKER_ARGS=
+# If there are at least 4 CPUs on this machine, restrict minio to 2
+# cores: goodput scales negatively at some point around 256 cores.
+if grep -q '^processor\s*:\s*3$' /proc/cpuinfo ;
+then
+    EXTRA_DOCKER_ARGS="$EXTRA_DOCKER_ARGS --cpuset-cpus=1-2"
+fi
+
+docker run --net=host $EXTRA_DOCKER_ARGS \
   --user $(id -u):$(id -g) \
   --name verneuil_test_minio \
   -v $CURRENT/minio:/data \
